==> haskell-wl-pprint-annotated-0.1.0.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-annotated.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-annotated
version: 0.1.0.1
id: wl-pprint-annotated-0.1.0.1-HyhhEmNPBhe6DYuGgWlFIZ
key: wl-pprint-annotated-0.1.0.1-HyhhEmNPBhe6DYuGgWlFIZ
license: BSD-3-Clause
copyright: 2011-2012 Edward A. Kmett, 2000 Daan Leijen
maintainer: Daniel Mendler <mail@daniel-mendler.de>
author: Daniel Mendler <mail@daniel-mendler.de>
stability: experimental
homepage: https://github.com/minad/wl-pprint-annotated#readme
synopsis: Pretty printer with annotation support
description:
    Wadler/Leijen pretty printer with support for annotations and modernized API. Annotations are useful for coloring. See wl-pprint-console.
category: Text
abi: d91a27b37b2d6b2f2438e7e1425e5878
exposed: True
exposed-modules:
    Text.PrettyPrint.Annotated.WL
hidden-modules: Paths_wl_pprint_annotated
import-dirs: /usr/lib/ghc-8.4.3/site-local/wl-pprint-annotated-0.1.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/wl-pprint-annotated-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wl-pprint-annotated-0.1.0.1
hs-libraries: HSwl-pprint-annotated-0.1.0.1-HyhhEmNPBhe6DYuGgWlFIZ
depends:
    base-4.11.1.0 containers-0.5.11.0 deepseq-1.4.3.0 text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-annotated/html/wl-pprint-annotated.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-annotated/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-annotated-0.1.0.1-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-annotated.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-annotated
version: 0.1.0.1
id: wl-pprint-annotated-0.1.0.1-D5RYhowxdoJJSZqcdmkEu9
key: wl-pprint-annotated-0.1.0.1-D5RYhowxdoJJSZqcdmkEu9
license: BSD-3-Clause
copyright: 2011-2012 Edward A. Kmett, 2000 Daan Leijen
maintainer: Daniel Mendler <mail@daniel-mendler.de>
author: Daniel Mendler <mail@daniel-mendler.de>
stability: experimental
homepage: https://github.com/minad/wl-pprint-annotated#readme
synopsis: Pretty printer with annotation support
description:
    Wadler/Leijen pretty printer with support for annotations and modernized API. Annotations are useful for coloring. See wl-pprint-console.
category: Text
abi: dde936a3dd244ddce2795fcc929eaf1c
exposed: True
exposed-modules:
    Text.PrettyPrint.Annotated.WL
hidden-modules: Paths_wl_pprint_annotated
import-dirs: /usr/lib/ghc-8.4.3/site-local/wl-pprint-annotated-0.1.0.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/wl-pprint-annotated-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wl-pprint-annotated-0.1.0.1
hs-libraries: HSwl-pprint-annotated-0.1.0.1-D5RYhowxdoJJSZqcdmkEu9
depends:
    base-4.11.1.0 containers-0.5.11.0 deepseq-1.4.3.0 text-1.2.3.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-annotated/html/wl-pprint-annotated.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-annotated/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
